Ian Jauslin
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'src/navier-stokes.c')
-rw-r--r--src/navier-stokes.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/navier-stokes.c b/src/navier-stokes.c
index fadc87e..24b4508 100644
--- a/src/navier-stokes.c
+++ b/src/navier-stokes.c
@@ -120,8 +120,8 @@ int energy(
return(0);
}
-// compute enstrophy as a function of time in the I-NS equation
-int enstrophy(
+// compute alpha as a function of time in the I-NS equation
+int alpha(
int K1,
int K2,
int N1,